@@ -8,33 +8,36 @@ datasets may be ingested from existing datasets and written to new
 datasets. This is so that datasets which are partially conformant may
 nonetheless be modified in memory.
 
-The `cf` package can:
+The `cf` package uses `dask` for all of its array manipulation and
+can:
 
-* read field constructs and domain constructs from netCDF, CDL, PP and
-  UM datasets,
+* read field constructs from netCDF, CDL, PP and UM datasets,
 
-* create new field and domain constructs in memory,
-
-* inspect field and domain constructs,
-
-* test whether two constructs are the same,
-
-* modify field and domain construct metadata and data,
-
-* create subspaces of field and domain constructs,
+* create new field constructs in memory,
 
 * write and append field constructs to netCDF datasets on disk,
 
-* incorporate, and create, metadata stored in external files,
-
-* read, write, and create data that have been compressed by convention
-  (i.e. ragged or gathered arrays), whilst presenting a view of the
-  data in its uncompressed form,
-
 * read, write, and create coordinates defined by geometry cells,
 
 * read netCDF and CDL datasets containing hierarchical groups,
 
+* inspect field constructs,
+
+* test whether two field constructs are the same,
+
+* modify field construct metadata and data,
+
+* create subspaces of field constructs,
+
+* write field constructs to netCDF datasets on disk,
+
+* incorporate, and create, metadata stored in external files,
+
+* read, write, and create data that have been compressed by convention
+  (i.e. ragged or gathered arrays, or coordinate arrays compressed by
+  subsampling), whilst presenting a view of the data in its
+  uncompressed form,
+
 * combine field constructs arithmetically,
 
 * manipulate field construct data by arithmetical and trigonometrical
@@ -51,20 +54,16 @@ The `cf` package can:
 
 * apply convolution filters to field constructs,
 
-* calculate derivatives of field constructs,
+* create running means from field constructs,
 
-* create field constructs to create derived quantities (such as
-  vorticity).
+* apply differential operators to field constructs,
 
-All of the above use LAMA functionality, which allows multiple fields
-larger than the available memory to exist and be manipulated. (Note:
-work is underway to replace this functionality with a dask
-implementation.)
+* create derived quantities (such as relative vorticity).
 
 
-**Visualization**
+**Visualisation**
 
-Powerful, flexible, and very simple to produce visualizations of field
+Powerful, flexible, and very simple to produce visualisations of field
 constructs uses the `cfplot` package
 (http://ajheaps.github.io/cf-plot), that is automatically installed
 along with with `cf`.
@@ -73,9 +72,10 @@ See the :ref:`cf-python home page <cf-python-home>` for documentation,
 installation and source code.
 
 """
-__Conventions__ = "CF-1.9"
-__date__ = "2022-10-17"
-__version__ = "3.13.1"
+
+__Conventions__ = "CF-1.10"
+__date__ = "2023-01-31"
+__version__ = "3.14.0"
 
 _requires = (
     "numpy",
@@ -84,6 +84,7 @@ _requires = (
     "cfunits",
     "cfdm",
     "psutil",
+    "dask",
     "packaging",
 )
 
@@ -103,10 +104,6 @@ import platform
 
 _found_ESMF = bool(importlib.util.find_spec("ESMF"))
 
-# TODODASK - Remove the next 2 lines when the move to dask is complete
-mpi_on = False
-mpi_size = 1
-
 try:
     import netCDF4
 except ImportError as error1:
@@ -132,6 +129,11 @@ try:
 except ImportError as error1:
     raise ImportError(_error0 + str(error1))
 
+try:
+    import dask
+except ImportError as error1:
+    raise ImportError(_error0 + str(error1))
+
 try:
     import packaging
 except ImportError as error1:
@@ -162,7 +164,7 @@ if Version(netCDF4.__version__) < Version(_minimum_vn):
     )
 
 # Check the version of cftime
-_minimum_vn = "1.5.0"
+_minimum_vn = "1.6.0"
 if Version(cftime.__version__) < Version(_minimum_vn):
     raise RuntimeError(
         f"Bad cftime version: cf requires cftime>={_minimum_vn}. "
@@ -170,7 +172,7 @@ if Version(cftime.__version__) < Version(_minimum_vn):
     )
 
 # Check the version of numpy
-_minimum_vn = "1.15"
+_minimum_vn = "1.22"
 if Version(numpy.__version__) < Version(_minimum_vn):
     raise RuntimeError(
         f"Bad numpy version: cf requires numpy>={_minimum_vn}. "
@@ -186,8 +188,8 @@ if Version(cfunits.__version__) < Version(_minimum_vn):
     )
 
 # Check the version of cfdm
-_minimum_vn = "1.9.0.4"
-_maximum_vn = "1.9.1.0"
+_minimum_vn = "1.10.0.2"
+_maximum_vn = "1.10.1.0"
 _cfdm_version = Version(cfdm.__version__)
 if not Version(_minimum_vn) <= _cfdm_version < Version(_maximum_vn):
     raise RuntimeError(
@@ -195,6 +197,14 @@ if not Version(_minimum_vn) <= _cfdm_version < Version(_maximum_vn):
         f"Got {_cfdm_version} at {cfdm.__file__}"
     )
 
+# Check the version of dask
+_minimum_vn = "2022.12.1"
+if Version(dask.__version__) < Version(_minimum_vn):
+    raise RuntimeError(
+        f"Bad dask version: cf requires dask>={_minimum_vn}. "
+        f"Got {dask.__version__} at {dask.__file__}"
+    )
+
 # Check the version of Python
 _minimum_vn = "3.7.0"
 if Version(platform.python_version()) < Version(_minimum_vn):
@@ -203,17 +213,18 @@ if Version(platform.python_version()) < Version(_minimum_vn):
         f"or later. Got {platform.python_version()}"
     )
 
-
 from .constructs import Constructs
 
 from .mixin import Coordinate
 
 from .count import Count
 from .index import Index
+from .interpolationparameter import InterpolationParameter
 from .list import List
 from .nodecountproperties import NodeCountProperties
 from .partnodecountproperties import PartNodeCountProperties
 from .interiorring import InteriorRing
+from .tiepointindex import TiePointIndex
 
 from .bounds import Bounds
 from .domain import Domain
@@ -238,14 +249,22 @@ from .domainancillary import DomainAncillary
 from .domainaxis import DomainAxis
 from .fieldancillary import FieldAncillary
 from .field import Field
-from .data import (
-    Data,
-    FilledArray,
+from .data import Data
+from .data.array import (
+    CFANetCDFArray,
+    FullArray,
     GatheredArray,
     NetCDFArray,
     RaggedContiguousArray,
     RaggedIndexedArray,
     RaggedIndexedContiguousArray,
+    SubsampledArray,
+)
+
+from .data.fragment import (
+    MissingFragmentArray,
+    NetCDFFragmentArray,
+    UMFragmentArray,
 )
 
 from .aggregate import aggregate
