@@ -1,6 +1,6 @@
 import logging
+import operator
 from collections import namedtuple
-from operator import __add__, __sub__
 
 import numpy
 
@@ -34,7 +34,7 @@ _one_second = Data(1, "second")
 # Default month lengths in days
 _default_month_lengths = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]
 
-_default_calendar = "gregorian"
+default_calendar = "gregorian"
 
 Offset = namedtuple(
     "offset",
@@ -245,7 +245,7 @@ class TimeDuration:
     def __init__(
         self, duration, units=None, month=1, day=1, hour=0, minute=0, second=0
     ):
-        """**Initialization**
+        """**Initialisation**
 
         :Parameters:
 
@@ -312,7 +312,7 @@ class TimeDuration:
                   (cftime.DatetimeGregorian(1999-12-30 00:00:00),
                    cftime.DatetimeGregorian(2000-01-30 00:00:00))
 
-        **Examples:**
+        **Examples**
 
         >>> t = cf.TimeDuration(cf.Data(3 , 'calendar_years'))
         >>> t = cf.TimeDuration(cf.Data(12 , 'hours'))
@@ -380,7 +380,7 @@ class TimeDuration:
         return out
 
     def __array__(self, *dtype):
-        """TODO."""
+        """Returns a `numpy` array representing the time duration."""
         return self.duration.__array__(*dtype)
 
     def __data__(self):
@@ -433,13 +433,7 @@ class TimeDuration:
 
         """
 
-        if isinstance(other, (self.__class__, int, float)):
-            return bool(self._binary_operation(other, "__ge__"))
-
-        if isinstance(other, Data):
-            return self._data_binary_operation(other, "__ge__")
-
-        return NotImplemented
+        return self._apply_binary_comparison(other, "__ge__")
 
     def __gt__(self, other):
         """The rich comparison operator ``>``
@@ -448,13 +442,7 @@ class TimeDuration:
 
         """
 
-        if isinstance(other, (self.__class__, int, float)):
-            return bool(self._binary_operation(other, "__gt__"))
-
-        if isinstance(other, Data):
-            return self._data_binary_operation(other, "__gt__")
-
-        return NotImplemented
+        return self._apply_binary_comparison(other, "__gt__")
 
     def __le__(self, other):
         """The rich comparison operator ``<=``
@@ -462,13 +450,7 @@ class TimeDuration:
         x.__le__(y) <==> x<=y
 
         """
-        if isinstance(other, (self.__class__, int, float)):
-            return bool(self._binary_operation(other, "__le__"))
-
-        if isinstance(other, Data):
-            return self._data_binary_operation(other, "__le__")
-
-        return NotImplemented
+        return self._apply_binary_comparison(other, "__le__")
 
     def __lt__(self, other):
         """The rich comparison operator ``<``
@@ -476,13 +458,7 @@ class TimeDuration:
         x.__lt__(y) <==> x<y
 
         """
-        if isinstance(other, (self.__class__, int, float)):
-            return bool(self._binary_operation(other, "__lt__"))
-
-        if isinstance(other, Data):
-            return self._data_binary_operation(other, "__lt__")
-
-        return NotImplemented
+        return self._apply_binary_comparison(other, "__lt__")
 
     def __eq__(self, other):
         """The rich comparison operator ``==``
@@ -490,13 +466,7 @@ class TimeDuration:
         x.__eq__(y) <==> x==y
 
         """
-        if isinstance(other, (self.__class__, int, float)):
-            return bool(self._binary_operation(other, "__eq__"))
-
-        if isinstance(other, Data):
-            return self._data_binary_operation(other, "__eq__")
-
-        return NotImplemented
+        return self._apply_binary_comparison(other, "__eq__")
 
     def __ne__(self, other):
         """The rich comparison operator ``!=``
@@ -504,13 +474,7 @@ class TimeDuration:
         x.__ne__(y) <==> x!=y
 
         """
-        if isinstance(other, (self.__class__, int, float)):
-            return bool(self._binary_operation(other, "__ne__"))
-
-        if isinstance(other, Data):
-            return self._data_binary_operation(other, "__ne__")
-
-        return NotImplemented
+        return self._apply_binary_comparison(other, "__ne__")
 
     def __add__(self, other):
         """The binary arithmetic operation ``+``
@@ -520,18 +484,9 @@ class TimeDuration:
         .. versionadded:: 1.4
 
         """
-        if isinstance(other, (self.__class__, int, float)):
-            return self._binary_operation(other, "__add__")
-
-        if hasattr(other, "timetuple"):
-            # other is a date-time object
-            try:
-                return self._datetime_arithmetic(other, __add__)
-            except TypeError:
-                return NotImplemented
-
-        if isinstance(other, Data):
-            return self._data_arithmetic(other, "__add__")
+        return self._apply_binary_arithmetic(
+            other, "__add__", may_be_datetime=True
+        )
 
         return NotImplemented
 
@@ -543,13 +498,9 @@ class TimeDuration:
         .. versionadded:: 1.4
 
         """
-        if isinstance(other, (self.__class__, int, float)):
-            return self._binary_operation(other, "__sub__")
-
-        if isinstance(other, Data):
-            return self._data_arithmetic(other, "__sub__")
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(
+            other, "__sub__", may_be_datetime=True
+        )
 
     def __mul__(self, other):
         """The binary arithmetic operation ``*``
@@ -557,13 +508,7 @@ class TimeDuration:
         x.__mul__(y) <==> x*y
 
         """
-        if isinstance(other, (int, float)):
-            return self._binary_operation(other, "__mul__")
-
-        if isinstance(other, Data):
-            return self._data_arithmetic(other, "__mul__")
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(other, "__mul__")
 
     def __div__(self, other):
         """The binary arithmetic operation ``/``
@@ -571,13 +516,7 @@ class TimeDuration:
         x.__div__(y) <==> x/y
 
         """
-        if isinstance(other, (int, float)):
-            return self._binary_operation(other, "__div__")
-
-        if isinstance(other, Data):
-            return self._data_arithmetic(other, "__div__")
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(other, "__div__")
 
     def __floordiv__(self, other):
         """The binary arithmetic operation ``//``
@@ -585,13 +524,7 @@ class TimeDuration:
         x.__floordiv__(y) <==> x//y
 
         """
-        if isinstance(other, (int, float)):
-            return self._binary_operation(other, "__floordiv__")
-
-        if isinstance(other, Data):
-            return self._data_arithmetic(other, "__floordiv__")
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(other, "__floordiv__")
 
     def __truediv__(self, other):
         """The binary arithmetic operation ``/`` (true division)
@@ -599,13 +532,7 @@ class TimeDuration:
         x.__truediv__(y) <==> x/y
 
         """
-        if isinstance(other, (int, float)):
-            return self._binary_operation(other, "__truediv__")
-
-        if isinstance(other, Data):
-            return self._data_arithmetic(other, "__truediv__")
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(other, "__truediv__")
 
     def __iadd__(self, other):
         """The augmented arithmetic assignment ``+=``
@@ -613,10 +540,9 @@ class TimeDuration:
         x.__iadd__(y) <==> x+=y
 
         """
-        if isinstance(other, (self.__class__, int, float)):
-            return self._binary_operation(other, "__iadd__", True)
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(
+            other, "__iadd__", aug_assignment=True, skip_data_return=True
+        )
 
     def __idiv__(self, other):
         """The augmented arithmetic assignment ``/=``
@@ -624,13 +550,9 @@ class TimeDuration:
         x.__idiv__(y) <==> x /= y
 
         """
-        if isinstance(other, (int, float)):
-            return self._binary_operation(other, "__idiv__", True)
-
-        if isinstance(other, Data):
-            return self._data_binary_operation(other, "__idiv__", True)
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(
+            other, "__idiv__", aug_assignment=True
+        )
 
     def __itruediv__(self, other):
         """The augmented arithmetic assignment ``/=`` (true division)
@@ -638,10 +560,9 @@ class TimeDuration:
         x.__truediv__(y) <==> x/y
 
         """
-        if isinstance(other, (int, float)):
-            return self._binary_operation(other, "__itruediv__", True)
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(
+            other, "__itruediv__", aug_assignment=True, skip_data_return=True
+        )
 
     def __ifloordiv__(self, other):
         """The augmented arithmetic assignment ``//=``
@@ -649,10 +570,9 @@ class TimeDuration:
         x.__ifloordiv__(y) <==> x//=y
 
         """
-        if isinstance(other, (int, float)):
-            return self._binary_operation(other, "__ifloordiv__", True)
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(
+            other, "__ifloordiv__", aug_assignment=True, skip_data_return=True
+        )
 
     def __imul__(self, other):
         """The augmented arithmetic assignment ``*=``
@@ -660,10 +580,9 @@ class TimeDuration:
         x.__imul__(y) <==> x *= y
 
         """
-        if isinstance(other, (int, float)):
-            return self._binary_operation(other, "__imul__", True)
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(
+            other, "__imul__", aug_assignment=True, skip_data_return=True
+        )
 
     def __isub__(self, other):
         """The augmented arithmetic assignment ``-=``
@@ -671,10 +590,9 @@ class TimeDuration:
         x.__isub__(y) <==> x -= y
 
         """
-        if isinstance(other, (self.__class__, int, float)):
-            return self._binary_operation(other, "__isub__", True)
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(
+            other, "__isub__", aug_assignment=True, skip_data_return=True
+        )
 
     def __imod__(self, other):
         """The augmented arithmetic assignment ``%=``
@@ -682,13 +600,9 @@ class TimeDuration:
         x.__imod__(y) <==> x%=y
 
         """
-        if isinstance(other, (int, float)):
-            return self._binary_operation(other, "__imod__", True)
-
-        if isinstance(other, Data):
-            return self._data_binary_operation(other, "__imod__", True)
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(
+            other, "__imod__", aug_assignment=True
+        )
 
     def __radd__(self, other):
         """The binary arithmetic operation ``+`` with reflected
@@ -717,17 +631,7 @@ class TimeDuration:
         .. versionadded:: 1.4
 
         """
-        if isinstance(other, (self.__class__, int, float)):
-            return self._binary_operation(other, "__rsub__")
-
-        if hasattr(other, "timetuple"):
-            # other is a date-time object
-            try:
-                return self._datetime_arithmetic(other, __sub__)
-            except TypeError:
-                return NotImplemented
-
-        return NotImplemented
+        return -self + other
 
     def __mod__(self, other):
         """The binary arithmetic operation ``%``
@@ -735,13 +639,7 @@ class TimeDuration:
         x.__mod__(y) <==> x % y
 
         """
-        if isinstance(other, (self.__class__, int, float)):
-            return self._binary_operation(other, "__mod__")
-
-        if isinstance(other, Data):
-            return self._data_arithmetic(other, "__mod__")
-
-        return NotImplemented
+        return self._apply_binary_arithmetic(other, "__mod__")
 
     def __rmod__(self, other):
         """The binary arithmetic operation ``%`` with reflected
@@ -758,8 +656,80 @@ class TimeDuration:
     # ----------------------------------------------------------------
     # Private methods
     # ----------------------------------------------------------------
+    def _apply_binary_comparison(self, other, op):
+        """Apply a binary comparison operation on general data.
+
+        .. versionadded:: 3.12.0
+
+        :Parameters:
+
+            other: the object to compare with.
+
+            op: `str`, the binary comparison operator to apply.
+
+        """
+
+        if isinstance(other, (self.__class__, int, float)):
+            return bool(self._binary_operation(other, op))
+
+        if isinstance(other, Data):
+            return self._data_binary_operation(other, op)
+
+        return NotImplemented
+
+    def _apply_binary_arithmetic(
+        self,
+        other,
+        op,
+        aug_assignment=False,
+        may_be_datetime=False,
+        skip_data_return=False,
+    ):
+        """Apply a binary arithmetic operation with general data.
+
+        .. versionadded:: 3.12.0
+
+        :Parameters:
+
+            other: the object to compare with.
+
+            op: `str`, the binary arithmetic operator to apply.
+
+            aug_assignment: `bool`
+                Whether the arithmetic operation is one of
+                augmented assignment. By default it is not.
+
+            may_be_datetime: `bool`
+                Whether it is logically permissible for other to be a
+                datetime, which is False by default.
+
+            skip_data_return: `bool`
+                Whether to skip logic to apply the operation on the
+                datetime data if other has Data type. By default,
+                do not skip.
+
+        """
+        check_simple_types = [int, float]
+        if may_be_datetime:
+            check_simple_types.append(self.__class__)
+
+        if isinstance(other, tuple(check_simple_types)):
+            return self._binary_operation(other, op, aug_assignment)
+
+        if may_be_datetime and hasattr(other, "timetuple"):
+            # other is a date-time object
+            try:
+                return self._datetime_arithmetic(other, getattr(operator, op))
+            except TypeError:
+                return NotImplemented
+
+        if not skip_data_return and isinstance(other, Data):
+            return self._data_arithmetic(other, op, aug_assignment)
+
+        return NotImplemented
+
     def _binary_operation(self, other, method, inplace=False):
-        """TODO."""
+        """Implement binary operations on the datetime."""
         if inplace:
             new = self
         else:
@@ -803,7 +773,7 @@ class TimeDuration:
         return new
 
     def _data_binary_operation(self, other, method, inplace=False):
-        """TODO."""
+        """Implement binary operations on the datetime data."""
         if inplace:
             new = self
         else:
@@ -812,7 +782,7 @@ class TimeDuration:
         return getattr(new.duration, method)(other)
 
     def _datetime_arithmetic(self, other, op):
-        """TODO.
+        """Apply binary arithmetic operations on the datetime.
 
         .. versionadded:: 1.4
 
@@ -871,21 +841,12 @@ class TimeDuration:
                 if d > max_days:
                     d = max_days
 
-            # TODO When cftime==1.1.4 is ready use this one line:
-            #            return other.replace(year=y, month=m, day=d)
-            # Instead of these try ... except ... lines:
-            try:
-                return other.replace(year=y, month=m, day=d, calendar=calendar)
-            except (ValueError, TypeError):
-                # If we are here, then 'other' is a datetime.datetime
-                # object, which doesn't have a 'calendar' keyword to
-                # its 'replace' method.
-                return other.replace(year=y, month=m, day=d)
+            return other.replace(year=y, month=m, day=d)
         else:
             return _dHMS(duration, other, calendar, op)
 
     def _data_arithmetic(self, other, method, inplace=False):
-        """TODO."""
+        """Apply binary arithmetic operations on the datetime data."""
         try:
             dt = other.datetime_array
         except ValueError:
@@ -903,17 +864,22 @@ class TimeDuration:
             return Data(dt, units=other.Units)
 
     def _offset(self, dt):
-        """TODO.
+        """Calculate the time duration offset.
 
         .. versionadded:: 1.4
 
         :Parameters:
 
-            dt: `cf.Datetime` TODO
+            dt: `cf.Datetime`
+                The date-time from which to calculate the offset.
+                *dt* may be any date-time-like object, such as
+                `cf.Datetime`, `datetime.datetime`,
+                `netCDF4.netcdftime.datetime`, etc.
 
         :Returns:
 
-            `Datetime` TODO
+            `Datetime`
+                The date-time object representing the offset.
 
         """
         return cf_dt(
@@ -934,7 +900,7 @@ class TimeDuration:
 
         .. versionadded:: 1.0
 
-        **Examples:**
+        **Examples**
 
         >>> cf.TimeDuration(45, 'days').iso
         'P45D'
@@ -973,7 +939,7 @@ class TimeDuration:
 
         .. versionadded:: 1.0
 
-        **Examples:**
+        **Examples**
 
         >>> cf.TimeDuration(2, 'hours').isint
         True
@@ -997,7 +963,7 @@ class TimeDuration:
 
         .. versionadded:: 1.0
 
-        **Examples:**
+        **Examples**
 
         >>> cf.TimeDuration(3, 'days').Units
         <CF Units: days>
@@ -1038,7 +1004,7 @@ class TimeDuration:
 
                 The deep copy.
 
-        **Examples:**
+        **Examples**
 
         >>> u = t.copy()
 
@@ -1060,10 +1026,12 @@ class TimeDuration:
         :Parameters:
 
             year: `int`
-                TODO
+                The calendar year to query.
 
             month: `int`
-                TODO
+                The one- or two-digit integer representing the calendar
+                month to query (numbered by order in the calendar year,
+                for example 2 for February, 10 for October).
 
             calendar: `str`, optional
                 By default, calendar is the mixed Gregorian/Julian
@@ -1082,7 +1050,7 @@ class TimeDuration:
             `int`
                 The number of days in the specified month.
 
-        **Examples:**
+        **Examples**
 
         >>> cf.TimeDuration.days_in_month(2004, 2, calendar='360_day')
         30
@@ -1122,7 +1090,7 @@ class TimeDuration:
 
         return length
 
-    @_deprecated_kwarg_check("traceback")
+    @_deprecated_kwarg_check("traceback", version="3.0.0", removed_at="4.0.0")
     @_manage_log_level_via_verbosity
     def equals(
         self, other, rtol=None, atol=None, verbose=None, traceback=False
@@ -1179,7 +1147,7 @@ class TimeDuration:
             `bool`
                 Whether or not the two instances are equal.
 
-        **Examples:**
+        **Examples**
 
         >>> t = cf.TimeDuration(36, 'calendar_months')
         >>> u = cf.TimeDuration(3, 'calendar_years')
@@ -1225,7 +1193,7 @@ class TimeDuration:
 
         return True
 
-    @_deprecated_kwarg_check("traceback")
+    @_deprecated_kwarg_check("traceback", version="3.0.0", removed_at="4.0.0")
     @_manage_log_level_via_verbosity
     def equivalent(
         self, other, rtol=None, atol=None, verbose=None, traceback=False
@@ -1282,7 +1250,7 @@ class TimeDuration:
             `bool`
                 Whether or not the two instances logically equivalent.
 
-        **Examples:**
+        **Examples**
 
         >>> t = cf.TimeDuration(36, 'calendar_months')
         >>> u = cf.TimeDuration(3, 'calendar_years')
@@ -1392,7 +1360,7 @@ class TimeDuration:
                 date-time. If *iso* has been set then an ISO 8601 time
                 interval string is returned instead of a tuple.
 
-        **Examples:**
+        **Examples**
 
         >>> t = cf.TimeDuration(6, 'calendar_months')
         >>> t
@@ -1468,9 +1436,9 @@ class TimeDuration:
             else:
                 return dt1, dt  # dt1, dt.copy()
 
-        calendar = getattr(dt, "calendar", _default_calendar)
+        calendar = getattr(dt, "calendar", default_calendar)
         if calendar == "":
-            calendar = _default_calendar
+            calendar = default_calendar
 
         dt = cf_dt(dt, calendar=calendar)
 
@@ -1553,7 +1521,7 @@ class TimeDuration:
 
         .. versionadded:: 1.2.3
 
-        .. seealso:: `cf.dt`, `cf.Datetime`, `interval` TODO
+        .. seealso:: `cf.dt`, `cf.Datetime`, `interval`, `offset`
 
         :Parameters:
 
@@ -1579,36 +1547,34 @@ class TimeDuration:
             `tuple`
                 The two bounds.
 
-        **Examples:**
-
-        TODO
+        **Examples**
 
         >>> t = cf.M()
         >>> t.bounds(cf.dt(2000, 1, 1))
-        (cftime.DatetimeGregorian(2000-01-01 00:00:00),
-         cftime.DatetimeGregorian(2000-02-01 00:00:00))
+        (cftime.DatetimeGregorian(2000, 1, 1, 0, 0, 0, 0, has_year_zero=False),
+         cftime.DatetimeGregorian(2000, 2, 1, 0, 0, 0, 0, has_year_zero=False))
 
         >>> t = cf.M(1)
         >>> t.bounds(cf.dt(2000, 3, 1))
-        (cftime.DatetimeGregorian(2000-03-01 00:00:00),
-         cftime.DatetimeGregorian(2000-04-01 00:00:00))
+        (cftime.DatetimeGregorian(2000, 3, 1, 0, 0, 0, 0, has_year_zero=False),
+         cftime.DatetimeGregorian(2000, 4, 1, 0, 0, 0, 0, has_year_zero=False))
 
         >>> t = cf.M(1, day=15)
         >>> t.bounds(cf.dt(2000, 3, 1))
-        (cftime.DatetimeGregorian(2000-02-15 00:00:00),
-         cftime.DatetimeGregorian(2000-03-15 00:00:00))
+        (cftime.DatetimeGregorian(2000, 2, 15, 0, 0, 0, 0, has_year_zero=False),
+         cftime.DatetimeGregorian(2000, 3, 15, 0, 0, 0, 0, has_year_zero=False))
 
         >>> t = cf.M(2, day=15)
         >>> t.bounds(cf.dt(2000, 3, 1), direction=False)
-        (cftime.DatetimeGregorian(2000-03-15 00:00:00),
-         cftime.DatetimeGregorian(2000-01-15 00:00:00))
+        (cftime.DatetimeGregorian(2000, 3, 15, 0, 0, 0, 0, has_year_zero=False),
+         cftime.DatetimeGregorian(2000, 1, 15, 0, 0, 0, 0, has_year_zero=False))
 
         """
         abs_self = abs(self)
 
-        calendar = getattr(dt, "calendar", _default_calendar)
+        calendar = getattr(dt, "calendar", default_calendar)
         if calendar == "":
-            calendar = _default_calendar
+            calendar = default_calendar
 
         dt = cf_dt(dt, calendar=calendar)
 
@@ -1635,7 +1601,7 @@ class TimeDuration:
 
             `bool`
 
-        **Examples:**
+        **Examples**
 
         >>> cf.TimeDuration(0.5, 'days').is_day_factor()
         True
@@ -1722,7 +1688,7 @@ def Y(duration=1, month=1, day=1, hour=0, minute=0, second=0):
         `TimeDuration`
             The new `cf.TimeDuration` object.
 
-    **Examples:**
+    **Examples**
 
     >>> cf.Y()
     <CF TimeDuration: P1Y (Y-01-01 00:00:00)>
@@ -1775,7 +1741,7 @@ def M(duration=1, month=1, day=1, hour=0, minute=0, second=0):
         `TimeDuration`
             The new `cf.TimeDuration` object.
 
-    **Examples:**
+    **Examples**
 
     >>> cf.M()
     <CF TimeDuration: P1M (Y-M-01 00:00:00)>
@@ -1826,7 +1792,7 @@ def D(duration=1, month=1, day=1, hour=0, minute=0, second=0):
         `TimeDuration`
             The new `cf.TimeDuration` object.
 
-    **Examples:**
+    **Examples**
 
     >>> cf.D()
     <CF TimeDuration: P1D (Y-M-D 00:00:00)>
@@ -1880,7 +1846,7 @@ def h(duration=1, month=1, day=1, hour=0, minute=0, second=0):
         `TimeDuration`
             The new `cf.TimeDuration` object.
 
-    **Examples:**
+    **Examples**
 
     >>> cf.h()
     <CF TimeDuration: PT1H (Y-M-D h:00:00)>
@@ -1934,7 +1900,7 @@ def m(duration=1, month=1, day=1, hour=0, minute=0, second=0):
         `TimeDuration`
             The new `cf.TimeDuration` object.
 
-    **Examples:**
+    **Examples**
 
     >>> cf.m()
     <CF TimeDuration: PT1M (Y-M-D h:m:00)>
@@ -1988,7 +1954,7 @@ def s(duration=1, month=1, day=1, hour=0, minute=0, second=0):
         `TimeDuration`
             The new `cf.TimeDuration` object.
 
-    **Examples:**
+    **Examples**
 
     >>> cf.s()
     <CF TimeDuration: PT1S (Y-M-D h:m:s)>
